| Title: | Visualize Simon's Two-Stage Design |
|---|---|
| Description: | To visualize the probabilities of early termination, fail and success of Simon's two-stage design. To evaluate and visualize the operating characteristics of Simon's two-stage design. |
| Authors: | Tingting Zhan [aut, cre] (ORCID: <https://orcid.org/0000-0001-9971-4844>) |
| Maintainer: | Tingting Zhan <[email protected]> |
| License: | GPL-2 |
| Version: | 0.2.3 |
| Built: | 2026-06-03 03:07:01 UTC |
| Source: | https://github.com/tingtingzhan/visualizesimon2stage |
To visualize the probabilities of early termination, fail and success of Simon's two-stage design. To evaluate and visualize the operating characteristics of Simon's two-stage design.
Help files of individual functions are intentionally suppressed in the pdf manual.
Users are encouraged to get started with
vignette('intro', package = 'VisualizeSimon2Stage')
Maintainer: Tingting Zhan [email protected] (ORCID)
Authors:
Tingting Zhan [email protected] (ORCID)
Power of ph2simon or ph2simon4 Object
power.ph2simon4( prob, object, ..., r1 = object@r1, n1 = object@n1, r = object@r, n = object@n ) power.ph2simon(prob, object, ...) powerCurve.ph2simon4(object, ...) powerCurve.ph2simon(object, ...)power.ph2simon4( prob, object, ..., r1 = object@r1, n1 = object@n1, r = object@r, n = object@n ) power.ph2simon(prob, object, ...) powerCurve.ph2simon4(object, ...) powerCurve.ph2simon(object, ...)
prob |
double scalar, true response rate |
object |
|
... |
parameters of function |
r1, n1, r, n
|